<img src="./docs/images/pygsuite_logo.png" width=20% height=20%>

# pygsuite

[![Join the chat at https://gitter.im/pygsuite/community](https://badges.gitter.im/pygsuite/community.svg)](https://gitter.im/pygsuite/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

This package provides utilities for working GSuite products such as sheets, docs, and slides 
in a pythonic, object-oriented way.

It currently offers abstractions for

- Drive
- Sheets
- Slides
- Docs

## Install

`pygsuite` is [hosted on PyPI](https://pypi.org/project/pygsuite/), and is installable with [pip](https://pip.pypa.io/en/stable/):

```bash
$ pip install pygsuite
```

## Documentation

[Read the Docs](https://pygsuite.readthedocs.io/en/latest/)

## Contributing

`pygsuite` is an open source project, and community contributions are very welcome. Before contributing, please check out our [contribution page]() as part of our documentation.
